interface TagFormatDefinition {}

interface TagCategoryDefinitions {
  [key: string]: TagFormatDefinition;
}

enum TagType {
  POI = 'poi',
  ROUTE = 'route',
}

interface TagActivityDefinitions {
  route?: { [key: string]: TagCategoryDefinitions };
  poi?: { [key: string]: TagCategoryDefinitions };
}

interface TagDefinitions {
  [key: string]: TagActivityDefinitions;
}

interface TagStatus {
  type?: TagType;
  definition?: TagFormatDefinition;
  highlighted: boolean;
}

export const getTagStatus = <TagStatus>(
  tag: string,
  definitions: TagDefinitions,
  selectedKey: string,
  highlightedKey: string
) => {
  const defaultStatus = {
    highlighted: false,
  } as TagStatus;
  const activityDefinitions = definitions[selectedKey];
  if (!activityDefinitions) {
    return defaultStatus;
  }

  for (const type of Object.values(TagType)) {
    const typeDefinitions = activityDefinitions[type as TagType];

    if (!!typeDefinitions) {
      const highlightedDefinitions = typeDefinitions[highlightedKey];

      if (!!highlightedDefinitions) {
        const definition = highlightedDefinitions[tag];
        if (!!definition) {
          return { type, definition, highlighted: true } as TagStatus;
        }
      }

      for (const category of Object.keys(typeDefinitions)) {
        if (category !== highlightedKey) {
          const categoryDefinitions = typeDefinitions[category];
          const definition = categoryDefinitions[tag];
          if (!!definition) {
            return { type, definition, highlighted: false } as TagStatus;
          }
        }
      }
    }
  }

  return defaultStatus;
};
